@@ -2,7 +2,7 @@
 # vim: sw=4:ts=4:et:cc=120
 from __future__ import annotations
 
-__version__ = "1.9.11"
+__version__ = "2.0.0"
 __doc__ = """
 Yara Scanner
 ============
@@ -475,7 +475,7 @@ class YaraRuleFile:
                 self.yara_rules.append(YaraRule(rule, namespace=self.namespace))
 
         except Exception as e:
-            log.warning(f"failed to parse {self.file_path} with plyara: {e}")
+            log.debug(f"failed to parse {self.file_path} with plyara: {e}")
 
             #
             # when a file fails to be parsed with plyara we assume something is wrong with plyara
@@ -541,7 +541,7 @@ class YaraContext:
         assert all([isinstance(_, YaraRuleFile) for _ in yara_rule_files])
 
         # the list of yara rules that are part of this context
-        self.yara_rules = sorted(yara_rules, key=lambda x: x.parsed_rule['rule_name'])
+        self.yara_rules = sorted(yara_rules, key=lambda x: x.parsed_rule["rule_name"])
 
         # the list of yara rule files that are also part of this context
         self.yara_rule_files = sorted(yara_rule_files, key=lambda x: x.file_path)
@@ -579,7 +579,7 @@ class YaraContext:
         self.sources = {namespace: "\n\n".join(sources) for namespace, sources in self.sources.items()}
 
         # compute the sha256 of the combined source files
-        # if we parsed out the yara rules then we don't do this because we cannot 
+        # if we parsed out the yara rules then we don't do this because we cannot
         # deterministically rebuild the yara rules
         if not self.yara_rules and compiled_rules_dir is not None:
             hasher = hashlib.sha256()
@@ -609,7 +609,7 @@ class YaraContext:
         self.compile_time_ms = int((end - start).total_seconds() * 1000)
         log.info(f"context compiled in {self.compile_time_ms} ms")
 
-        # if we parsed out the yara rules then we don't do this because we cannot 
+        # if we parsed out the yara rules then we don't do this because we cannot
         # deterministically rebuild the yara rules
         if not self.yara_rules and compiled_rules_dir:
             log.debug(f"saving compiled yara rules to {compiled_rules_dir}")
@@ -953,7 +953,7 @@ class YaraScanner(Filterable):
                     parser = plyara.Plyara()
                     parsed_rule_list = parser.parse_string(yara_rule_file.source)
                 except Exception as e:  # pragma: no cover
-                    log.warning(f"yara rule {yara_rule_file.file_path} is unparsable with plyara: {e}")
+                    log.debug(f"yara rule {yara_rule_file.file_path} is unparsable with plyara: {e}")
                     continue
             else:
                 # otherwise we can just use the parsing we did when we loaded the rules
@@ -1838,7 +1838,7 @@ def read_n_bytes(s, n):
 
     result = b"".join(_buffer)
     if len(result) != n:
-        log.warning(f"expected {n} bytes but read {len(result)}")
+        log.debug(f"expected {n} bytes but read {len(result)}")
 
     return b"".join(_buffer)
 
@@ -2042,11 +2042,11 @@ def main():  # pragma: no cover
     )
 
     parser.add_argument(
-        "--disable-prefilter",
-        dest="disable_prefilter",
+        "--enable-prefilter",
+        dest="enable_prefilter",
         action="store_true",
         default=False,
-        help="Disable prefiltering rules to boost scanning performance.",
+        help="Enable prefiltering rules. WARNING: This slows down the initialization process.",
     )
 
     parser.add_argument(
@@ -2069,7 +2069,7 @@ def main():  # pragma: no cover
     parser.add_argument(
         "--auto-compiled-rules-dir",
         help="""Specifies the directory to use to store automatically compiled
-        yara rules. Defaults to the system temp dir.""",
+        yara rules. Defaults to ~/.yara_scanner.""",
     )
 
     args = parser.parse_args()
@@ -2102,7 +2102,7 @@ def main():  # pragma: no cover
 
     scanner = YaraScanner(
         signature_dir=args.signature_dir,
-        disable_prefilter=args.disable_prefilter,
+        disable_prefilter=not args.enable_prefilter,
         disable_postfilter=args.disable_postfilter,
         compiled_rules_dir=compiled_rules_dir,
     )
